@@ -1161,7 +1161,7 @@ float db_get_totalfill(enum dbtimespan timespan)
 }
 
 /**
- * \fn int db_get_yearly_consum(int **year, int **numfills, float **minconsum, float **avgconsum, float **maxconsum)
+ * \fn int db_get_yearly_consum(int **year, int **numfills, double **minconsum, double **avgconsum, double **maxconsum)
  * \brief Get the minimun, maximum and average consumption of currentcar
  * \param **year The year output table
  * \param **numfills How many fill events for given year
@@ -1173,7 +1173,7 @@ float db_get_totalfill(enum dbtimespan timespan)
  * Tables are allocated in this function and must be freed after usage.
  *
  */
-int db_get_yearly_consum(int **year, int **numfills, float **minconsum, float **avgconsum, float **maxconsum)
+int db_get_yearly_consum(int **year, int **numfills, double **minconsum, double **avgconsum, double **maxconsum)
 {
   char **sqlresult;
   char *sqlquery;
@@ -1200,15 +1200,15 @@ int db_get_yearly_consum(int **year, int **numfills, float **minconsum, float **
 	  resultsize=sqlrows;
 	  *year=(int *)malloc((resultsize)*sizeof(int));
 	  *numfills=(int *)malloc((resultsize)*sizeof(int));
-	  *minconsum=(float *)malloc((resultsize)*sizeof(float));
-	  *avgconsum=(float *)malloc((resultsize)*sizeof(float));
-	  *maxconsum=(float *)malloc((resultsize)*sizeof(float));
+	  *minconsum=(double *)malloc((resultsize)*sizeof(double));
+	  *avgconsum=(double *)malloc((resultsize)*sizeof(double));
+	  *maxconsum=(double *)malloc((resultsize)*sizeof(double));
 	  for (i=1;i<=resultsize;i++) {
 	    (*year)[i-1]=(int)atof_l(sqlresult[i*sqlcolumns],"C");
 	    (*numfills)[i-1]=(int)atof_l(sqlresult[i*sqlcolumns+1],"C");
-	    (*minconsum)[i-1]=(float)atof_l(sqlresult[i*sqlcolumns+2],"C");
-	    (*avgconsum)[i-1]=(float)atof_l(sqlresult[i*sqlcolumns+3],"C");
-	    (*maxconsum)[i-1]=(float)atof_l(sqlresult[i*sqlcolumns+4],"C");
+	    (*minconsum)[i-1]=(double)atof_l(sqlresult[i*sqlcolumns+2],"C");
+	    (*avgconsum)[i-1]=(double)atof_l(sqlresult[i*sqlcolumns+3],"C");
+	    (*maxconsum)[i-1]=(double)atof_l(sqlresult[i*sqlcolumns+4],"C");
 	  } // for
 	}
       } // if(rc==SQLITE_OK)
@@ -1226,7 +1226,7 @@ int db_get_yearly_consum(int **year, int **numfills, float **minconsum, float **
 }
 
 /**
- * \fn int db_get_consum_bin(int year, float minconsum, float maxconsum)
+ * \fn int db_get_consum_bin(int year, double minconsum, double maxconsum)
  * \brief Get the number of trip consumptions between minconsum and maxconsum
  * \param year The year
  * \param minconsum Lower limit of the bin
@@ -1234,7 +1234,7 @@ int db_get_yearly_consum(int **year, int **numfills, float **minconsum, float **
  * \return Number of trip consumptions between minconsum and maxconsum
  *
  */
-int db_get_consum_bin(int year, float minconsum, float maxconsum)
+int db_get_consum_bin(int year, double minconsum, double maxconsum)
 {
   char **sqlresult;
   char *sqlquery;
