@@ -113,21 +113,21 @@ gboolean report_key_press_cb(GtkWidget * widget, GdkEventKey * event,
 {
   switch (event->keyval) {
 
-    case GDK_F6:
+    case HILDON_HARDKEY_FULLSCREEN:
       gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(pui->report_menu_item_fullscreen),
 				     !pui->reportfullscreen);
       return TRUE;
-    case GDK_Down:
+    case HILDON_HARDKEY_DOWN:
       report_scroll(pui,FALSE);
       return TRUE;
       break;
-    case GDK_Up:
+    case HILDON_HARDKEY_UP  :
       report_scroll(pui,TRUE);
       return TRUE;
-    case GDK_F7:
+    case HILDON_HARDKEY_INCREASE:
       report_zoom(pui->reportcanvas, ZOOMIN);
       return TRUE;
-    case GDK_F8:
+    case HILDON_HARDKEY_DECREASE:
       report_zoom(pui->reportcanvas, ZOOMOUT);
       return TRUE;
       break;
@@ -755,6 +755,9 @@ void report_response (GtkDialog *dialog, gint arg1, AppUIData *pui)
 #endif
    hildon_program_add_window(pui->app->program, pui->app->reportwindow);
 
+#if MAEMO_VERSION_MAJOR == 5
+   hildon_gtk_window_enable_zoom_keys(GTK_WINDOW(pui->app->reportwindow), TRUE);
+#endif
   /* Callback for hardware keys */
   g_signal_connect(G_OBJECT(pui->app->reportwindow), "key_press_event",
 		   G_CALLBACK(report_key_press_cb), pui);
